import requests

class ChatBot:
    def __init__(self):

    def chat(self, message):
        try:
            url = f"https://developer-server-g05b.onrender.com/chat_ai"

            data = {
                "message": message
            }

            res = requests.post(url, json=data, timeout=10)

            if res.status_code == 200:
                return res.json()
            else:
                return {"error": f"Status code: {res.status_code}"}

        except requests.exceptions.ConnectionError as e:
            return {"error": f"Connection Error: {e}"}

        except requests.exceptions.Timeout as e:
            return {"error": f"Timeout Error: {e}"}

        except requests.exceptions.RequestException as e:
            return {"error": f"Request Error: {e}"}

        except Exception as e:
            return {"error": f"Unknown Error: {e}"}


from setuptools import setup, find_packages

setup(
    name="MST-AI",  # PyPI package name
    version="0.1.2",
    author="Rocky420-python",
    author_email="p13077795@gmail.com",
    description="A simple AI ChatBot Python library",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/Rocky420-python/MTS",
    packages=find_packages(),  # Automatically finds 'mst_ai' folder
    python_requires=">=3.8",
    install_requires=[
        "requests>=2.28.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)